@@ -57,11 +57,11 @@ def test_serialize_workflow():
 
     search_node = workflow_raw_data["nodes"][1]
     assert search_node == {
-        "id": "ab3a1413-c7b5-4cb0-a2d4-f5ab7d1d65b4",
+        "id": "89c8bee0-8015-4d73-9112-e436ab086567",
         "type": "SEARCH",
         "inputs": [
             {
-                "id": "49d21956-6e62-472b-b62a-7ec65faea1fd",
+                "id": "1dbfd1d9-8e8e-47b6-bb65-c578385ef978",
                 "key": "query",
                 "value": {
                     "rules": [
@@ -74,7 +74,7 @@ def test_serialize_workflow():
                 },
             },
             {
-                "id": "8cb28a69-088d-410d-bd0d-886d57ce7b64",
+                "id": "8f197069-4729-4db3-811c-9a522685dfba",
                 "key": "document_index_id",
                 "value": {
                     "rules": [{"type": "CONSTANT_VALUE", "data": {"type": "STRING", "value": "name"}}],
@@ -82,7 +82,7 @@ def test_serialize_workflow():
                 },
             },
             {
-                "id": "983f2b7f-ad86-45cf-b04b-08724af27236",
+                "id": "dd991fc6-5690-496b-b63e-b1a1219f3682",
                 "key": "weights",
                 "value": {
                     "rules": [
@@ -95,7 +95,7 @@ def test_serialize_workflow():
                 },
             },
             {
-                "id": "8072ec05-5fe4-47db-bc48-4c20ce49e123",
+                "id": "52f6c3ab-cd96-4ca7-bfb1-7554c431b318",
                 "key": "limit",
                 "value": {
                     "rules": [{"type": "CONSTANT_VALUE", "data": {"type": "JSON", "value": None}}],
@@ -103,7 +103,7 @@ def test_serialize_workflow():
                 },
             },
             {
-                "id": "051c5d2e-4667-4ae2-9202-1076b21adf7b",
+                "id": "e1822f91-ca9c-46c9-8dcd-cce83fe331ce",
                 "key": "separator",
                 "value": {
                     "rules": [{"type": "CONSTANT_VALUE", "data": {"type": "STRING", "value": "\n\n#####\n\n"}}],
@@ -111,7 +111,7 @@ def test_serialize_workflow():
                 },
             },
             {
-                "id": "8aac5dac-209e-48f3-97e1-0a39e4cd98d5",
+                "id": "3ee2bc2a-d72a-471a-8dd6-5e5028db8bfe",
                 "key": "result_merging_enabled",
                 "value": {
                     "rules": [{"type": "CONSTANT_VALUE", "data": {"type": "STRING", "value": "False"}}],
@@ -119,7 +119,7 @@ def test_serialize_workflow():
                 },
             },
             {
-                "id": "036dee8f-194a-4b92-9739-69c98a4aa1b9",
+                "id": "5c766934-13f7-4a0f-a751-21e25fd2ca30",
                 "key": "external_id_filters",
                 "value": {
                     "rules": [{"type": "CONSTANT_VALUE", "data": {"type": "JSON", "value": None}}],
@@ -127,7 +127,7 @@ def test_serialize_workflow():
                 },
             },
             {
-                "id": "855d3f57-e633-467e-a348-a394360247df",
+                "id": "977d75bc-520f-447b-ad75-8b56c793f951",
                 "key": "metadata_filters",
                 "value": {
                     "rules": [
@@ -167,7 +167,7 @@ def test_serialize_workflow():
                     "rules": [
                         {
                             "type": "INPUT_VARIABLE",
-                            "data": {"input_variable_id": "b118247f-96dd-4b3e-8289-9f277483c520"},
+                            "data": {"input_variable_id": "67fd852b-789b-4c18-8465-2bbf1696b8eb"},
                         }
                     ],
                     "combinator": "OR",
@@ -180,7 +180,7 @@ def test_serialize_workflow():
                     "rules": [
                         {
                             "type": "INPUT_VARIABLE",
-                            "data": {"input_variable_id": "aae2c10a-88b7-40bd-87a2-5e1e60c1e906"},
+                            "data": {"input_variable_id": "58e909b0-9269-454d-b40d-3846fd2c39f2"},
                         }
                     ],
                     "combinator": "OR",
@@ -193,7 +193,7 @@ def test_serialize_workflow():
                     "rules": [
                         {
                             "type": "INPUT_VARIABLE",
-                            "data": {"input_variable_id": "c9611a62-d1f5-4b41-bf9c-1aa3355760b4"},
+                            "data": {"input_variable_id": "7564f9c7-b2cf-4584-b4c7-845a14ac4dfa"},
                         }
                     ],
                     "combinator": "OR",
@@ -206,7 +206,7 @@ def test_serialize_workflow():
                     "rules": [
                         {
                             "type": "INPUT_VARIABLE",
-                            "data": {"input_variable_id": "f374640e-a5c0-470e-ac71-c36c2b198c00"},
+                            "data": {"input_variable_id": "cd081063-ab26-4ec7-99b3-af7e035a16e3"},
                         }
                     ],
                     "combinator": "OR",
@@ -215,19 +215,19 @@ def test_serialize_workflow():
         ],
         "data": {
             "label": "Simple Search Node",
-            "results_output_id": "e27fa934-589a-48f7-92a9-dcc90710ec7b",
-            "text_output_id": "3f3bd066-ce73-46ee-84f1-d8ece69ecd8c",
+            "results_output_id": "184c5214-29be-4029-8ece-2991972e0822",
+            "text_output_id": "9bab7f1b-3a4b-46bf-8b30-e3016ac38f51",
             "error_output_id": None,
-            "source_handle_id": "00ae06b3-f8d9-4ae6-9fbf-e4ff4d520e9b",
-            "target_handle_id": "6d50305f-588b-469f-a042-b0767d3f99b1",
-            "query_node_input_id": "49d21956-6e62-472b-b62a-7ec65faea1fd",
-            "document_index_node_input_id": "8cb28a69-088d-410d-bd0d-886d57ce7b64",
-            "weights_node_input_id": "983f2b7f-ad86-45cf-b04b-08724af27236",
-            "limit_node_input_id": "8072ec05-5fe4-47db-bc48-4c20ce49e123",
-            "separator_node_input_id": "051c5d2e-4667-4ae2-9202-1076b21adf7b",
-            "result_merging_enabled_node_input_id": "8aac5dac-209e-48f3-97e1-0a39e4cd98d5",
-            "external_id_filters_node_input_id": "036dee8f-194a-4b92-9739-69c98a4aa1b9",
-            "metadata_filters_node_input_id": "855d3f57-e633-467e-a348-a394360247df",
+            "source_handle_id": "928c79f2-bc07-43ee-9420-380a3bd36fb8",
+            "target_handle_id": "85db938d-9a85-4f08-8bbf-b795db2c40d5",
+            "query_node_input_id": "1dbfd1d9-8e8e-47b6-bb65-c578385ef978",
+            "document_index_node_input_id": "8f197069-4729-4db3-811c-9a522685dfba",
+            "weights_node_input_id": "dd991fc6-5690-496b-b63e-b1a1219f3682",
+            "limit_node_input_id": "52f6c3ab-cd96-4ca7-bfb1-7554c431b318",
+            "separator_node_input_id": "e1822f91-ca9c-46c9-8dcd-cce83fe331ce",
+            "result_merging_enabled_node_input_id": "3ee2bc2a-d72a-471a-8dd6-5e5028db8bfe",
+            "external_id_filters_node_input_id": "5c766934-13f7-4a0f-a751-21e25fd2ca30",
+            "metadata_filters_node_input_id": "977d75bc-520f-447b-ad75-8b56c793f951",
         },
         "display_data": {"position": {"x": 200.0, "y": -50.0}},
         "base": {
@@ -239,10 +239,10 @@ def test_serialize_workflow():
             "module": ["tests", "workflows", "basic_search_node", "workflow"],
         },
         "trigger": {
-            "id": "6d50305f-588b-469f-a042-b0767d3f99b1",
+            "id": "85db938d-9a85-4f08-8bbf-b795db2c40d5",
             "merge_behavior": "AWAIT_ANY",
         },
-        "ports": [{"id": "00ae06b3-f8d9-4ae6-9fbf-e4ff4d520e9b", "name": "default", "type": "DEFAULT"}],
+        "ports": [{"id": "928c79f2-bc07-43ee-9420-380a3bd36fb8", "name": "default", "type": "DEFAULT"}],
     }
 
     final_output_node = workflow_raw_data["nodes"][2]
@@ -266,8 +266,8 @@ def test_serialize_workflow():
                         {
                             "type": "NODE_OUTPUT",
                             "data": {
-                                "node_id": "ab3a1413-c7b5-4cb0-a2d4-f5ab7d1d65b4",
-                                "output_id": "3f3bd066-ce73-46ee-84f1-d8ece69ecd8c",
+                                "node_id": "89c8bee0-8015-4d73-9112-e436ab086567",
+                                "output_id": "9bab7f1b-3a4b-46bf-8b30-e3016ac38f51",
                             },
                         }
                     ],
@@ -287,17 +287,17 @@ def test_serialize_workflow():
     serialized_edges = workflow_raw_data["edges"]
     assert serialized_edges == [
         {
-            "id": "06533904-4897-4a7a-aa8d-50419b3d33ae",
+            "id": "16500e66-1e19-4ee3-a197-baf9c2926ae4",
             "source_node_id": "06671b25-5c6b-4675-8c74-6c396a608728",
             "source_handle_id": "df80b4aa-2ba1-49a2-8375-fb1f78eee31f",
-            "target_node_id": "ab3a1413-c7b5-4cb0-a2d4-f5ab7d1d65b4",
-            "target_handle_id": "6d50305f-588b-469f-a042-b0767d3f99b1",
+            "target_node_id": "89c8bee0-8015-4d73-9112-e436ab086567",
+            "target_handle_id": "85db938d-9a85-4f08-8bbf-b795db2c40d5",
             "type": "DEFAULT",
         },
         {
             "id": "cb918deb-f546-47b5-8b6b-db0d22a29fd1",
-            "source_node_id": "ab3a1413-c7b5-4cb0-a2d4-f5ab7d1d65b4",
-            "source_handle_id": "00ae06b3-f8d9-4ae6-9fbf-e4ff4d520e9b",
+            "source_node_id": "89c8bee0-8015-4d73-9112-e436ab086567",
+            "source_handle_id": "928c79f2-bc07-43ee-9420-380a3bd36fb8",
             "target_node_id": "4e466510-6756-403f-a182-56e5a2b85d94",
             "target_handle_id": "cd8c736f-1b77-493d-b857-d8feb5c03b15",
             "type": "DEFAULT",
