@@ -30,6 +30,7 @@ from vellum.workflows.events.workflow import (
 from vellum.workflows.exceptions import WorkflowInitializationException
 from vellum.workflows.inputs.base import BaseInputs
 from vellum.workflows.nodes.bases.base import BaseNode
+from vellum.workflows.nodes.displayable.tool_calling_node.utils import ElseNode, RouterNode
 from vellum.workflows.outputs.base import BaseOutput
 from vellum.workflows.references.vellum_secret import VellumSecretReference
 from vellum.workflows.state.base import BaseState
@@ -134,6 +135,7 @@ mock_node_uuid = str(MockNode.__id__)
                         "id": mock_node_uuid,
                         "name": "MockNode",
                         "module": module_root + ["events", "tests", "test_event"],
+                        "exclude_from_monitoring": False,
                     },
                     "inputs": {
                         "node_foo": "bar",
@@ -147,6 +149,7 @@ mock_node_uuid = str(MockNode.__id__)
                         "id": mock_node_uuid,
                         "name": "MockNode",
                         "module": module_root + ["events", "tests", "test_event"],
+                        "exclude_from_monitoring": False,
                     },
                     "parent": {
                         "workflow_definition": {
@@ -340,6 +343,7 @@ mock_node_uuid = str(MockNode.__id__)
                         "id": mock_node_uuid,
                         "name": "MockNode",
                         "module": module_root + ["events", "tests", "test_event"],
+                        "exclude_from_monitoring": False,
                     },
                     "output": {
                         "name": "example",
@@ -376,6 +380,7 @@ mock_node_uuid = str(MockNode.__id__)
                         "id": mock_node_uuid,
                         "name": "MockNode",
                         "module": module_root + ["events", "tests", "test_event"],
+                        "exclude_from_monitoring": False,
                     },
                     "outputs": {
                         "example": "foo",
@@ -417,6 +422,7 @@ mock_node_uuid = str(MockNode.__id__)
                         "id": mock_node_uuid,
                         "name": "MockNode",
                         "module": module_root + ["events", "tests", "test_event"],
+                        "exclude_from_monitoring": False,
                     },
                     "outputs": {},
                     "invoked_ports": [
@@ -456,6 +462,7 @@ mock_node_uuid = str(MockNode.__id__)
                         "id": mock_node_uuid,
                         "name": "MockNode",
                         "module": module_root + ["events", "tests", "test_event"],
+                        "exclude_from_monitoring": False,
                     },
                     "outputs": {"example": "foo"},
                     "mocked": True,
@@ -532,3 +539,37 @@ def test_workflow_event_generator_stream_initialization_exception():
 
     assert initiated_event.trace_id == rejected_event.trace_id
     assert initiated_event.span_id == rejected_event.span_id
+
+
+def test_node_execution_initiated_event_includes_exclude_from_monitoring():
+    """Test exclude_from_monitoring is included in node_definition when node has __exclude_from_monitoring__."""
+    router_node_event = NodeExecutionInitiatedEvent(
+        id=UUID("123e4567-e89b-12d3-a456-426614174001"),
+        timestamp=datetime(2024, 1, 1, 12, 0, 0, tzinfo=timezone.utc),
+        trace_id=UUID("123e4567-e89b-12d3-a456-426614174001"),
+        span_id=UUID("123e4567-e89b-12d3-a456-426614174001"),
+        body=NodeExecutionInitiatedBody(
+            node_definition=RouterNode,
+            inputs={},
+        ),
+    )
+
+    serialized = router_node_event.model_dump(mode="json")
+    assert "exclude_from_monitoring" in serialized["body"]["node_definition"]
+    assert serialized["body"]["node_definition"]["exclude_from_monitoring"] is True
+
+    # Test with ElseNode
+    else_node_event = NodeExecutionInitiatedEvent(
+        id=UUID("123e4567-e89b-12d3-a456-426614174000"),
+        timestamp=datetime(2024, 1, 1, 12, 0, 0, tzinfo=timezone.utc),
+        trace_id=UUID("123e4567-e89b-12d3-a456-426614174000"),
+        span_id=UUID("123e4567-e89b-12d3-a456-426614174000"),
+        body=NodeExecutionInitiatedBody(
+            node_definition=ElseNode,
+            inputs={},
+        ),
+    )
+
+    serialized = else_node_event.model_dump(mode="json")
+    assert "exclude_from_monitoring" in serialized["body"]["node_definition"]
+    assert serialized["body"]["node_definition"]["exclude_from_monitoring"] is True
