@@ -88,12 +88,14 @@ class ExternalParentContext(BaseParentContext):
     type: Literal["EXTERNAL"] = "EXTERNAL"
 
 
-class WorkflowDeploymentScheduledTriggerContext(BaseParentContext):
+class ScheduledTriggerContext(BaseParentContext):
     type: Literal["SCHEDULED"] = "SCHEDULED"
+    trigger_id: UUID
 
 
-class WorkflowDeploymentIntegrationTriggerContext(BaseParentContext):
+class IntegrationTriggerContext(BaseParentContext):
     type: Literal["INTEGRATION"] = "INTEGRATION"
+    trigger_id: UUID
 
 
 class SpanLink(UniversalBaseModel):
@@ -161,8 +163,8 @@ ParentContext = Annotated[
         WorkflowSandboxParentContext,
         APIRequestParentContext,
         ExternalParentContext,
-        WorkflowDeploymentScheduledTriggerContext,
-        WorkflowDeploymentIntegrationTriggerContext,
+        ScheduledTriggerContext,
+        IntegrationTriggerContext,
         UnknownParentContext,
     ],
     ParentContextDiscriminator(),
