@@ -309,6 +309,8 @@ class BaseNode(Generic[StateType], ABC, BaseExecutable, metaclass=BaseNodeMeta):
     _context: WorkflowContext
     _inputs: MappingProxyType[Union[NodeReference, AccessorExpression], Any]
 
+    __exclude_from_monitoring__: bool = False
+
     class ExternalInputs(BaseInputs):
         __descriptor_class__ = ExternalInputReference
 
@@ -544,6 +546,16 @@ class BaseNode(Generic[StateType], ABC, BaseExecutable, metaclass=BaseNodeMeta):
     def run(self) -> NodeRunResponse:
         return self.Outputs()
 
+    def __cancel__(self, message: str) -> None:
+        """
+        Called when the node should be cancelled. Override this method to propagate
+        cancellation to nested workflows or other resources.
+
+        Args:
+            message: The error message describing why the node is being cancelled
+        """
+        pass
+
     def __repr__(self) -> str:
         return str(self.__class__)
 
