@@ -114,6 +114,10 @@ class FinalOutputNode(BaseNode[StateType], Generic[StateType, _OutputType], meta
     This provides backward compatibility with Vellum's Final Output Node.
     """
 
+    class Display(BaseNode.Display):
+        icon = "vellum:icon:circle-stop"
+        color = "teal"
+
     class Trigger(BaseNode.Trigger):
         merge_behavior = MergeBehavior.AWAIT_ANY
 
