@@ -159,7 +159,7 @@ class ToolPromptNode(InlinePromptNode[ToolCallingState]):
 class RouterNode(BaseNode[ToolCallingState]):
     """Router node that handles routing to function nodes based on outputs."""
 
-    pass
+    __exclude_from_monitoring__: bool = True  # Exclude from monitoring views
 
 
 class DynamicSubworkflowDeploymentNode(SubworkflowDeploymentNode[ToolCallingState], FunctionCallNodeMixin):
@@ -217,6 +217,9 @@ class FunctionNode(BaseNode[ToolCallingState], FunctionCallNodeMixin):
 
     function_definition: Callable[..., Any]
 
+    class Outputs(BaseNode.Outputs):
+        result: Any
+
     def run(self) -> Iterator[BaseOutput]:
         arguments = self._extract_function_arguments()
 
@@ -228,7 +231,7 @@ class FunctionNode(BaseNode[ToolCallingState], FunctionCallNodeMixin):
         # Add the result to the chat history
         self._add_function_result_to_chat_history(result, self.state)
 
-        yield from []
+        yield BaseOutput(name="result", value=result)
 
 
 class ComposioNode(BaseNode[ToolCallingState], FunctionCallNodeMixin):
@@ -263,6 +266,9 @@ class MCPNode(BaseNode[ToolCallingState], FunctionCallNodeMixin):
 
     mcp_tool: MCPToolDefinition
 
+    class Outputs(BaseNode.Outputs):
+        result: Any
+
     def run(self) -> Iterator[BaseOutput]:
         arguments = self._extract_function_arguments()
 
@@ -275,7 +281,7 @@ class MCPNode(BaseNode[ToolCallingState], FunctionCallNodeMixin):
         # Add result to chat history
         self._add_function_result_to_chat_history(result, self.state)
 
-        yield from []
+        yield BaseOutput(name="result", value=result)
 
 
 class VellumIntegrationNode(BaseNode[ToolCallingState], FunctionCallNodeMixin):
@@ -283,6 +289,9 @@ class VellumIntegrationNode(BaseNode[ToolCallingState], FunctionCallNodeMixin):
 
     vellum_integration_tool: VellumIntegrationToolDefinition
 
+    class Outputs(BaseNode.Outputs):
+        result: Any
+
     def run(self) -> Iterator[BaseOutput]:
         arguments = self._extract_function_arguments()
         vellum_client = self._context.vellum_client
@@ -314,12 +323,14 @@ class VellumIntegrationNode(BaseNode[ToolCallingState], FunctionCallNodeMixin):
         # Add result to chat history
         self._add_function_result_to_chat_history(result, self.state)
 
-        yield from []
+        yield BaseOutput(name="result", value=result)
 
 
 class ElseNode(BaseNode[ToolCallingState]):
     """Node that executes when no function conditions match."""
 
+    __exclude_from_monitoring__: bool = True  # Exclude from monitoring views
+
     class Ports(BaseNode.Ports):
         # Redefined in the create_else_node function, but defined here to resolve mypy errors
         loop_to_router = Port.on_if(
