@@ -1,11 +1,10 @@
 from enum import Enum
+from multiprocessing.synchronize import Event as MultiprocessingEvent
+from threading import Event as ThreadingEvent
 from typing import (  # type: ignore[attr-defined]
-    TYPE_CHECKING,
     Any,
-    Callable,
     Dict,
     List,
-    Type,
     Union,
     _GenericAlias,
     _SpecialGenericAlias,
@@ -13,21 +12,13 @@ from typing import (  # type: ignore[attr-defined]
 )
 
 from vellum.client.core.pydantic_utilities import UniversalBaseModel
-from vellum.workflows.types.definition import (
-    ComposioToolDefinition,
-    DeploymentDefinition,
-    MCPServer,
-    VellumIntegrationToolDefinition,
-)
-
-if TYPE_CHECKING:
-    from vellum.workflows.workflows.base import BaseWorkflow
-
 
 JsonArray = List["Json"]
 JsonObject = Dict[str, "Json"]
 Json = Union[None, bool, int, float, str, JsonArray, JsonObject]
 
+CancelSignal = Union[ThreadingEvent, MultiprocessingEvent]
+
 # Unions and Generics inherit from `_GenericAlias` instead of `type`
 # In future versions of python, we'll see `_UnionGenericAlias`
 UnderGenericAlias = _GenericAlias
@@ -53,14 +44,3 @@ class ConditionType(Enum):
     IF = "IF"
     ELIF = "ELIF"
     ELSE = "ELSE"
-
-
-# Type alias for functions that can be called in tool calling nodes
-ToolBase = Union[
-    Callable[..., Any],
-    DeploymentDefinition,
-    Type["BaseWorkflow"],
-    ComposioToolDefinition,
-    VellumIntegrationToolDefinition,
-]
-Tool = Union[ToolBase, MCPServer]
